all.Cycms<-function(){
     cat("\n")
     note_for_Cycss_input()
     cat("\n")
     note_for_close_window()
     CycMSpar<-data.frame(subject=c(1,2),bw=c(0),PTD=c(0),Dia=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     CycMSpar<-edit(CycMSpar)
##     CycMSpar<-ymscheck(CycMSpar)
     cat("\n")
     Cyc.ms(length(CycMSpar$subject),CycMSpar$c,CycMSpar$PTD,CycMSpar$tau,CycMSpar$ts,CycMSpar$D,CycMSpar$bw,CycMSpar$Dia)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Cycss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Cyccpr(CycMSpar$PTD,CycMSpar$bw,CycMSpar$D,CycMSpar$tau,CycMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-Cyccpr(CycMSpar$PTD,CycMSpar$bw,CycMSpar$D,CycMSpar$tau,CycMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n") 
     cal.again()
}